@@ -26,7 +26,7 @@ from os.path import abspath, dirname, join as joinpath, normpath, sep, splitext
 from shutil import rmtree
 from typing import cast, overload, Any, Literal
 
-from alist import AlistClient, AlistPath
+from alist.component import AlistClient, AlistPath
 from httpx import TimeoutException
 
 
@@ -37,12 +37,14 @@ logger.setLevel(logging.DEBUG)
 
 
 def alist_update_115_cookies(
-    client: AlistClient, 
+    client: str | AlistClient, 
     cookies: str, 
     only_not_work: bool = False, 
 ):
     """更新 alist 中有关 115 的存储的 cookies
     """
+    if isinstance(client, str):
+        client = AlistClient.from_auth(client)
     storages = client.admin_storage_list()["data"]["content"]
     for storage in storages:
         if storage["driver"] in ("115 Cloud", "115 Share"):
@@ -55,7 +57,7 @@ def alist_update_115_cookies(
 
 
 def alist_batch_add_115_share_links(
-    client: AlistClient, 
+    client: str | AlistClient, 
     share_links: str | Iterable[str], 
     cookies: str, 
     mount_root: str = "/", 
@@ -76,6 +78,8 @@ def alist_batch_add_115_share_links(
         run([executable, "-m", "pip", "install", "-U", "python-115", "python-retrytools"], check=True)
         from p115 import P115ShareFileSystem
         from retrytools import retry
+    if isinstance(client, str):
+        client = AlistClient.from_auth(client)
     if isinstance(share_links, str):
         share_links = (share_links,)
     mount_root = mount_root.strip("/")
@@ -130,7 +134,7 @@ def alist_batch_add_115_share_links(
 
 @overload
 def alist_batch_download(
-    client: None | AlistClient = None, 
+    client: None | str | AlistClient = None, 
     remote_dir: str = "/", 
     local_dir: str = "", 
     predicate: None | Literal[False] | Container[str] | Callable[[AlistPath], bool] = None, 
@@ -139,7 +143,7 @@ def alist_batch_download(
     password: str = "", 
     refresh: bool = False, 
     resume: bool = True, 
-    max_workers: int = 5, 
+    max_workers: int = 1, 
     logger = logger, 
     sync: bool = False, 
     *, 
@@ -148,7 +152,7 @@ def alist_batch_download(
     ...
 @overload
 def alist_batch_download(
-    client: None | AlistClient = None, 
+    client: None | str | AlistClient = None, 
     remote_dir: str = "/", 
     local_dir: str = "", 
     predicate: None | Literal[False] | Container[str] | Callable[[AlistPath], bool] = None, 
@@ -157,7 +161,7 @@ def alist_batch_download(
     password: str = "", 
     refresh: bool = False, 
     resume: bool = True, 
-    max_workers: int = 5, 
+    max_workers: int = 1, 
     logger = logger, 
     sync: bool = False, 
     *, 
@@ -165,7 +169,7 @@ def alist_batch_download(
 ) -> Coroutine[Any, Any, dict[str, bool]]:
     ...
 def alist_batch_download(
-    client: None | AlistClient = None, 
+    client: None | str | AlistClient = None, 
     remote_dir: str = "/", 
     local_dir: str = "", 
     predicate: None | Literal[False] | Container[str] | Callable[[AlistPath], bool] = None, 
@@ -174,7 +178,7 @@ def alist_batch_download(
     password: str = "", 
     refresh: bool = False, 
     resume: bool = True, 
-    max_workers: int = 5, 
+    max_workers: int = 1, 
     logger = logger, 
     sync: bool = False, 
     *, 
@@ -207,6 +211,8 @@ def alist_batch_download(
     """
     if client is None:
         client = AlistClient()
+    elif isinstance(client, str):
+        client = AlistClient.from_auth(client)
     remote_dir = client.fs.abspath(remote_dir)
     local_dir = abspath(local_dir)
     if predicate is False or predicate is None:
